@@ -1,5 +1,4 @@
 #![cfg(feature = "swarm")]
-#![cfg_attr(docsrs, doc(cfg(feature = "swarm")))]
 //! Configs are application configurations that can be used by services.
 //! Swarm mode must be enabled for these endpoints to work.
 
@@ -19,7 +18,7 @@ impl<'docker> Config<'docker> {
 impl<'docker> Configs<'docker> {
     impl_api_ep! { __: Config, resp
         List -> "/configs"
-        Create -> "/configs/create".into(), resp.id
+        Create -> "/configs/create", resp.id
     }
 }
 
