@@ -396,19 +396,24 @@ macro_rules! impl_api_ep {
         )*
     };
     (
-        Inspect $it:ident: $base:ident -> $resp:ident $ep:expr $(,$extra:expr)*
+        Inspect $it:ident: $base:ident -> $resp:ident $ep:expr, $ret:tt $(,$extra:expr)*
     ) => {
         paste::item! {
         api_doc! { $base => Inspect
         #[doc = concat!("Inspect this ", stringify!($base), ".")]
         |
-        pub async fn inspect(&self) -> Result<[< $base Info >]> {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &$base| $ep;
-            let ep = ep_fn(self);
+        pub async fn inspect(&self) -> Result<[< $base $ret >]> {
+            let ep_fn = Box::new(|$it: &$base| $ep);
+            let ep: String = ep_fn(self);
             self.docker.get_json(ep.as_ref()).await
         }}
         }
     };
+    (
+        Inspect $it:ident: $base:ident -> $resp:ident $ep:expr $(,$extra:expr)*
+    ) => {
+        impl_api_ep! { Inspect $it: $base -> $resp $ep, Info }
+    };
     (
         ForceDelete $it:ident: $base:ident -> $resp:ident $ep:expr, $ret:tt $(,$extra:expr)*
     ) => {
@@ -421,7 +426,7 @@ macro_rules! impl_api_ep {
                 None
             };
 
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &$base| $ep;
+            let ep_fn= Box::new(|$it: &$base| $ep);
             let ep = ep_fn(self);
             let ep = crate::util::url::construct_ep(ep, query);
 
@@ -455,7 +460,7 @@ macro_rules! impl_api_ep {
         #[doc = concat!("Delete this ", stringify!($base), ".")]
         |
         pub async fn delete(&self) -> Result<()> {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &$base| $ep;
+            let ep_fn= Box::new(|$it: &$base| $ep);
             let ep = ep_fn(self);
             self.docker.delete(ep.as_ref()).await.map(|_| ())
         }}
@@ -470,7 +475,7 @@ macro_rules! impl_api_ep {
         #[doc = concat!("Use [`delete`](", stringify!($base), "::delete) to delete without options.")]
         |
         pub async fn remove(&self, opts: &[< Rm $base Opts >]) -> Result<[< $ret >]> {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &$base| $ep;
+            let ep_fn= Box::new(|$it: &$base| $ep);
             let ep = ep_fn(self);
             let ep = crate::util::url::construct_ep(ep, opts.serialize());
             self.docker.delete_json(ep.as_ref()).await
@@ -482,7 +487,7 @@ macro_rules! impl_api_ep {
         #[doc = concat!("Use [`remove`](", stringify!($base), "::remove) to customize options.")]
         |
         pub async fn delete(&self) -> Result<[< $ret >]> {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &$base| $ep;
+            let ep_fn= Box::new(|$it: &$base| $ep);
             let ep = ep_fn(self);
             self.docker.delete_json(ep.as_ref()).await
         }}
@@ -504,15 +509,7 @@ macro_rules! impl_api_ep {
     (
         List $it:ident: $base:ident -> $resp:ident $ep:expr $(, $extra:expr)*
     ) => {
-        paste::item! {
-        api_doc! { $base => List
-        #[doc = concat!("List available ", stringify!($base), "s.")]
-        |
-        pub async fn list(&self, opts: &[< $base ListOpts >]) -> Result<Vec<[< $base Info >]>> {
-            let ep = crate::util::url::construct_ep($ep, opts.serialize());
-            self.docker.get_json(&ep).await
-        }}
-        }
+        impl_api_ep! { List $it: $base -> $resp $ep, [< $base  Info >] }
     };
     (
         Create $it:ident: $base:ident -> $resp:ident $ep:expr $(, $extra:expr)*
@@ -522,9 +519,7 @@ macro_rules! impl_api_ep {
         #[doc = concat!("Create a new ", stringify!($base), ".")]
         |
         pub async fn create(&self, opts: &[< $base CreateOpts >]) -> Result<[< $base >]<'_>> {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &[< $base s >]| $ep;
-            let ep = ep_fn(self);
-            self.docker.post_json(&ep, Payload::Json(opts.serialize()?)).await
+            self.docker.post_json(&$ep, Payload::Json(opts.serialize()?)).await
             .map(|$resp: [< $base CreateInfo >]| [< $base >]::new(self.docker, $($extra)*))
         }}
         }
@@ -556,7 +551,7 @@ macro_rules! impl_api_ep {
             &self,
             opts: &crate::api::LogsOpts
         ) -> impl futures_util::Stream<Item = crate::Result<crate::conn::TtyChunk>> + Unpin + 'docker {
-            let ep_fn: &dyn Fn(&Self) -> String = &|$it: &[< $base >]| $ep;
+            let ep_fn= Box::new(|$it: &[< $base >]| $ep);
             let ep = ep_fn(self);
             let ep = crate::util::url::construct_ep(ep, opts.serialize());
 
